@@ -4,7 +4,7 @@ This is a simple mailing list manager that mimicks the ezmlm-idx mail
 address commands. See manual page for more information.
 """
 
-VERSION = "1.2.4"
+VERSION = "1.2.6"
 PLUGIN_INTERFACE_VERSION = "1"
 
 import getopt
@@ -551,7 +551,7 @@ class MailingList:
         
             return "\n".join(headers) + "\n\n" + body
         except:
-            warning("Cannot MIME encode header, using original ones, sorry")
+            info("Cannot MIME encode header, using original ones, sorry")
             return text
 
     def template(self, template_name, dict):
@@ -657,7 +657,7 @@ class MailingList:
                                           "boundary": self.invent_boundary(),
                                        })
         else:
-            self.info_message([recipient], "setlist-sorry", {})
+            self.send_info_message([recipient], "setlist-sorry", {})
 
     def parse_setlist_addresses(self, text):
         body = text.split("\n\n", 1)[1]
