@@ -244,6 +244,30 @@ class DotDirTestCases(unittest.TestCase):
         mlm = eoc.MailingListManager(DOTDIR)
         self.dotdir_is_ok()
 
+
+class RemoveSomeHeadersTest(unittest.TestCase):
+
+    def testRemoveSomeHeaders(self):
+        mlm = eoc.MailingListManager(DOTDIR)
+        ml = eoc.MailingList(mlm, "list@example.com")
+        mail = """\
+Header-1: this is a simple header
+Header-2: this
+    is
+    a
+    complex header with a colon: yes it is
+Header-3: odd numbered headers are simple
+
+Body.
+"""
+        mail2 = ml.remove_some_headers(mail, ["Header-2"])
+        self.failUnlessEqual(mail2, """\
+Header-1: this is a simple header
+Header-3: odd numbered headers are simple
+
+Body.
+""")
+
 class ListBase(unittest.TestCase):
 
     def setUp(self):
